==> webservices-osgi-2.2-b03-sources.jar: com/sun/tools/ws/processor/generator/GeneratorExtension.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 1997-2011 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package com.sun.tools.ws.processor.generator;

import com.sun.codemodel.JCodeModel;
import com.sun.codemodel.JDefinedClass;
import com.sun.tools.ws.processor.model.Model;
import com.sun.tools.ws.processor.model.Port;
import com.sun.tools.ws.wscompile.WsimportOptions;
import com.sun.xml.ws.api.SOAPVersion;

/**
 * Service Generator Extension for Custom Binding and Transport
 * 
 * @since 2.2.6
 * @see JwsImplGenerator
 */
public abstract class GeneratorExtension {
    
    /**
     * Derive  Binding ID based on transport and SOAP version 
     * @param transport
     * @param soapVersion
     * @return BindingID
     */
    public String getBindingValue(String transport, SOAPVersion soapVersion) {
      return null;
    }
    
    /**
     * Create annotations in service JWS generated
     * @param model
     * @param cm
     * @param cls
     * @param port
     */
    public void writeWebServiceAnnotation(Model model, JCodeModel cm, JDefinedClass cls, Port port) {
    }
    
    /**
     * Allow additional wsimport options 
     * @param name, for instance, "-neoption"
     * @return whether the name specifies an option recognized by the extension
     */
    public boolean validateOption(String name) {
      return false;
    }
    
    /**
     * Create annotations in service client generated
     * @param options
     * @param cm
     * @param cls
     */
    public void writeWebServiceClientAnnotation(WsimportOptions options, JCodeModel cm, JDefinedClass cls) {
    }
}

==> webservices-osgi-2.4.7-sources.jar: com/sun/tools/ws/processor/generator/GeneratorExtension.java <==
/*
 * Copyright (c) 1997, 2018 Oracle and/or its affiliates. All rights reserved.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Distribution License v. 1.0, which is available at
 * http://www.eclipse.org/org/documents/edl-v10.php.
 *
 * SPDX-License-Identifier: BSD-3-Clause
 */

package com.sun.tools.ws.processor.generator;

import com.sun.codemodel.JCodeModel;
import com.sun.codemodel.JDefinedClass;
import com.sun.tools.ws.processor.model.Model;
import com.sun.tools.ws.processor.model.Port;
import com.sun.tools.ws.wscompile.WsimportOptions;
import com.sun.xml.ws.api.SOAPVersion;

/**
 * Service Generator Extension for Custom Binding and Transport
 * 
 * @since 2.2.6
 * @see JwsImplGenerator
 */
public abstract class GeneratorExtension {
    
    /**
     * Derive  Binding ID based on transport and SOAP version 
     * @param transport
     * @param soapVersion
     * @return BindingID
     */
    public String getBindingValue(String transport, SOAPVersion soapVersion) {
      return null;
    }
    
    /**
     * Create annotations in service JWS generated
     * @param model
     * @param cm
     * @param cls
     * @param port
     */
    public void writeWebServiceAnnotation(Model model, JCodeModel cm, JDefinedClass cls, Port port) {
    }
    
    /**
     * Allow additional wsimport options 
     * @param name for instance, "-neoption"
     * @return whether the name specifies an option recognized by the extension
     */
    public boolean validateOption(String name) {
      return false;
    }
    
    /**
     * Create annotations in service client generated
     * @param options
     * @param cm
     * @param cls
     */
    public void writeWebServiceClientAnnotation(WsimportOptions options, JCodeModel cm, JDefinedClass cls) {
    }
}
